@@ -5,11 +5,21 @@ from sqlalchemy_declarative_extensions.api import (
     declare_database,
     register_sqlalchemy_events,
 )
+from sqlalchemy_declarative_extensions.function import (
+    Function,
+    Functions,
+    register_function,
+)
 from sqlalchemy_declarative_extensions.grant import Grants
 from sqlalchemy_declarative_extensions.role import Role
 from sqlalchemy_declarative_extensions.role.base import Roles
 from sqlalchemy_declarative_extensions.row import Row, Rows
 from sqlalchemy_declarative_extensions.schema import Schema, Schemas
+from sqlalchemy_declarative_extensions.trigger import (
+    Trigger,
+    Triggers,
+    register_trigger,
+)
 from sqlalchemy_declarative_extensions.view import (
     View,
     ViewIndex,
@@ -21,20 +31,26 @@ from sqlalchemy_declarative_extensions.view import (
 __all__ = [
     "declarative_database",
     "declare_database",
-    "Grants",
-    "Role",
-    "Row",
-    "Rows",
     "dialects",
+    "Function",
+    "Functions",
+    "Grants",
     "register_alembic_events",
     "register_sqlalchemy_events",
+    "register_function",
+    "register_trigger",
     "register_view",
     "Role",
+    "Role",
     "Roles",
+    "Row",
+    "Rows",
     "Schema",
     "Schemas",
-    "view",
+    "Trigger",
+    "Triggers",
     "View",
+    "view",
     "ViewIndex",
     "Views",
 ]
