@@ -3,11 +3,14 @@ from sqlalchemy_declarative_extensions.dialects.query import (
     check_schema_exists,
     check_table_exists,
     get_default_grants,
+    get_function_cls,
+    get_functions,
     get_grants,
     get_objects,
     get_role_cls,
     get_roles,
     get_schemas,
+    get_triggers,
     get_view,
     get_views,
 )
@@ -16,13 +19,16 @@ __all__ = [
     "check_schema_exists",
     "check_table_exists",
     "get_default_grants",
+    "get_function_cls",
     "get_grants",
     "get_objects",
     "get_role_cls",
     "get_roles",
     "get_schemas",
+    "get_triggers",
     "get_view",
     "get_views",
+    "get_functions",
     "mysql",
     "postgresql",
     "sqlite",
