@@ -21,10 +21,12 @@ def get_views_mysql(connection: Connection):
 
 
 def check_schema_exists_mysql(connection: Connection, name: str) -> bool:
-    row = connection.execute(schema_exists_query, schema=name).scalar()
+    row = connection.execute(schema_exists_query, {"schema": name}).scalar()
     return not bool(row)
 
 
 def check_table_exists_mysql(connection: Connection, name: str, *, schema: str) -> bool:
-    row = connection.execute(table_exists_query, name=name, schema=schema).scalar()
+    row = connection.execute(
+        table_exists_query, {"name": name, "schema": schema}
+    ).scalar()
     return bool(row)
