@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Container, cast, List
+from typing import Container, List, cast
 
 from sqlalchemy.engine import Connection
 
@@ -8,18 +8,27 @@ from sqlalchemy_declarative_extensions.dialects.postgresql.acl import (
     parse_acl,
     parse_default_acl,
 )
+from sqlalchemy_declarative_extensions.dialects.postgresql.function import Function
 from sqlalchemy_declarative_extensions.dialects.postgresql.role import Role
 from sqlalchemy_declarative_extensions.dialects.postgresql.schema import (
     default_acl_query,
+    functions_query,
     object_acl_query,
     objects_query,
     roles_query,
     schema_exists_query,
     schemas_query,
     table_exists_query,
+    triggers_query,
     view_query,
     views_query,
 )
+from sqlalchemy_declarative_extensions.dialects.postgresql.trigger import (
+    Trigger,
+    TriggerEvents,
+    TriggerForEach,
+    TriggerTimes,
+)
 from sqlalchemy_declarative_extensions.sql import qualify_name
 from sqlalchemy_declarative_extensions.view.base import View, ViewIndex
 
@@ -149,3 +158,40 @@ def get_view_postgresql(connection: Connection, name: str, schema: str = "public
         result.definition,
         schema=result.schema if result.schema != "public" else None,
     )
+
+
+def get_functions_postgresql(connection: Connection):
+    functions = []
+    for f in connection.execute(functions_query).fetchall():
+        function = Function(
+            name=f.name,
+            definition=f.source,
+            returns=f.return_type,
+            language=f.language,
+            schema=f.schema if f.schema != "public" else None,
+        )
+        functions.append(function)
+    return functions
+
+
+def get_triggers_postgresql(connection: Connection):
+    triggers = []
+    for t in connection.execute(triggers_query).fetchall():
+        on = t.on_name if t.on_schema == "public" else f"{t.on_schema}.{t.on_name}"
+        execute = (
+            t.execute_name
+            if t.execute_schema == "public"
+            else f"{t.execute_schema}.{t.execute_name}"
+        )
+        trigger = Trigger(
+            name=t.name,
+            on=on,
+            execute=execute,
+            events=TriggerEvents.from_bit_string(t.type),
+            time=TriggerTimes.from_bit_string(t.type),
+            for_each=TriggerForEach.from_bit_string(t.type),
+            condition=t.when.lstrip("(").rstrip(")"),
+        )
+        triggers.append(trigger)
+
+    return triggers
