@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import uuid
 from dataclasses import dataclass, field, replace
-from typing import Any, Callable, Container, Iterable, TypeVar, cast, List
+from typing import Any, Callable, Container, Iterable, List, TypeVar, cast
 
 from sqlalchemy import Index, MetaData, UniqueConstraint, text
 from sqlalchemy.engine import Connection, Dialect
@@ -168,12 +168,12 @@ class View:
             )
         )
 
-    def render_definition(self, conn: Connection):
+    def render_definition(self, conn: Connection, using_connection: bool = True):
         dialect = conn.engine.dialect
 
         compiled_definition = self.compile_definition(dialect)
 
-        if dialect.name == "postgresql":
+        if using_connection and dialect.name == "postgresql":
             from sqlalchemy_declarative_extensions.dialects import get_view
 
             with conn.begin_nested() as trans:
@@ -231,7 +231,9 @@ class View:
             result.append(query)
         return result
 
-    def normalize(self, conn: Connection, metadata: MetaData) -> View:
+    def normalize(
+        self, conn: Connection, metadata: MetaData, using_connection: bool = True
+    ) -> View:
         constraints = None
         if self.constraints:
             constraints = [
@@ -240,7 +242,9 @@ class View:
             ]
 
         return replace(
-            self, definition=self.render_definition(conn), constraints=constraints
+            self,
+            definition=self.render_definition(conn, using_connection=using_connection),
+            constraints=constraints,
         )
 
     def to_sql_create(self, dialect: Dialect) -> list[str]:
@@ -270,8 +274,9 @@ class View:
             result.extend(from_view.to_sql_drop(dialect))
             result.extend(self.to_sql_create(dialect))
         else:
-            result.extend(from_view.render_constraints(create=False))
-            result.extend(self.render_constraints(create=True))
+            removed, missing = ViewIndex.diff(from_view.constraints, self.constraints)  # type: ignore
+            result.extend([c.drop(from_view) for c in removed])
+            result.extend([c.create(self) for c in missing])
 
         return result
 
@@ -285,8 +290,9 @@ class View:
 
         statement = " ".join(components)
 
-        result = [statement]
+        result = []
         result.extend(self.render_constraints(create=False))
+        result.append(statement)
 
         return result
 
@@ -422,6 +428,34 @@ class ViewIndex:
         name = qualify_name(on.schema, self.name, quote=True)
         return f"DROP INDEX {name};"
 
+    @staticmethod
+    def diff(
+        existing_indices: list[ViewIndex] | None,
+        declared_indices: list[ViewIndex] | None,
+    ) -> tuple[list[ViewIndex], list[ViewIndex]]:
+        removed = []
+        missing = []
+
+        existing_by_name = {x.name: x for x in existing_indices or []}
+        declared_by_name = {x.name: x for x in declared_indices or []}
+
+        for name, existing in existing_by_name.items():
+            declared = declared_by_name.pop(name, None)
+            if declared:
+                # We need to replace ones which are declared but different in some way
+                if existing != declared:
+                    removed.append(existing)
+                    missing.append(declared)
+            else:
+                # Whereas if they're not declared they should be removed.
+                removed.append(existing)
+
+        # The pop from above means anything left is automatically missing.
+        for declared in declared_by_name.values():
+            missing.append(declared)
+
+        return (removed, missing)
+
 
 @dataclass
 class _ViewIndexAdapter:
@@ -445,10 +479,6 @@ class _ViewIndexAdapter:
     def columns(self):
         return [_ColumnNamingAdapter(c) for c in self.view_index.columns]
 
-    @property
-    def expressions(self):
-        return self.view_index.columns
-
 
 @dataclass
 class _ColumnNamingAdapter:
